## Nucleus: A Tool for Bioinformaticians. 

Just as software developers have Visual Studio Code, bioinformaticians now have Nucleus.

Nucleus is designed to simplify bioinformatics workflows by integrating powerful language models with essential bioinformatics tools. 

![Descriptive Alt Text](https://pratikkatte.github.io/nucleus-bio/assets/demo.gif)

## Installation
```
pip install nucleus-chat
```

## Getting Started

```
# Navigate to your desired project directory. 
cd /to/your/project

# Nucleus currently supports OpenAI models.

# Use OpenAI 4o on your files
nucleus --openai-api-key your-key-goes-here

```

Refer to usage [documentation](https://pratikkatte.github.io/nucleus-bio/docs/Usage) for more details.

## Features
- Ask for queries related to bioinformatic tools and commands. 

## Upcoming Features
- Integration of BioWASM tools to eliminate the need for local installation of bioinformatics software.
- Visualizae bioinformatics file formats.
- Search and download bioinformatics datasets directly.

<!-- ## Kind words from users -->

